betty.gui.serve module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.gui.serve module

Integrate Betty’s Graphical User Interface with the Serve API.

final class betty.gui.serve.ServeDemoWindow

  Bases: `_ServeWindow`

  A window to control the demonstration site server.

  Parameters:

    - app (`betty.app.App`)

    - parent (`PyQt6.QtCore.QObject` | `None`)

  property window_title: Localizable

    The human-readable short title of this window.

final class betty.gui.serve.ServeDocsWindow

  Bases: `_ServeWindow`

  A window to control the documentation server.

  Parameters:

    - app (`betty.app.App`)

    - parent (`PyQt6.QtCore.QObject` | `None`)

  property window_title: Localizable

    The human-readable short title of this window.

final class betty.gui.serve.ServeProjectWindow

  Bases: `_ServeWindow`

  A window to control the server for the current project.

  Parameters:

    - app (`betty.app.App`)

    - parent (`PyQt6.QtCore.QObject` | `None`)

  property window_title: Localizable

    The human-readable short title of this window.